Authors
=======

Lead Developers & Organizers
----------------------------
- `Yalin Li <zoe.yalin.li@gmail.com>`_ (current maintainer)
- `Joy Cheung <joycheung1994@gmail.com>`_
- `Stetson Rowles <lsr@illinois.edu>`_


Code Development
----------------
- `Yalin Li <zoe.yalin.li@gmail.com>`_
- `Joy Cheung <joycheung1994@gmail.com>`_
- `Other developers <https://github.com/QSD-Group/QSDsan/graphs/contributors>`_ that have contributed to the repository.


Module Development
------------------
- `Yalin Li <zoe.yalin.li@gmail.com>`_
- `Joy Cheung <joycheung1994@gmail.com>`_
- `Stetson Rowles <lsr@illinois.edu>`_
- Tori Morgan
- Hannah Lohman
- Smiti Mittal
- Anna Kogler
- Samuel Aguiar
- Taylor Stephen
- Shion Watabe


Project Conception
------------------
- `Jeremy Guest <jsguest@illinois.edu>`_


Funding Support
---------------
- `Jeremy Guest <jsguest@illinois.edu>`_
- William Tarpeh
- Ro Cusick


Special Acknowledgement
-----------------------
- Yoel Cortés-Peña for helping many of the ``QSDsan`` members get started on Python and package development.
